Pbkdf

Trait Pbkdf 

pub trait Pbkdf: Kdf { }
Password-Based Key Derivation Functions: KDFs where it’s suitable for the input secret to be a user-specified password, which employ algorithms designed to be resistant to brute-force attacks.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors